@@ -8,7 +8,7 @@ client = TestClient(app)
 
 def test_main():
     response = client.get("/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert b"<!DOCTYPE html>" in response.content
 
 
